==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Search:</source>
        <translation type="vanished">Keres:</translation>
    </message>
    <message>
        <source>Add Widget</source>
        <translation type="vanished">Bigyó hozzáadás</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Bezár</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Párbeszédablak</translation>
    </message>
</context>
<context>
    <name>LXQt::AboutDialogPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation type="vanished">Verzió: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Qt alapú könnyen használható, fejlett és gyors asztalkezelő.</translation>
    </message>
    <message>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Az LXQt a &lt;a %1&gt;Razor-qt&lt;/a&gt;-és annak fejlesztői nélkül nem létezne.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Jogok: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Honlap: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation type="vanished">Licensz: %1</translation>
    </message>
    <message>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">Az LXQt fejlesztői&lt;a %1&gt;LXQt Team és a társasága&lt;/a&gt;</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation type="vanished">Ha érdekli a fejlesztés. akkor &lt;a %1&gt;csatlakozhat hozzánk&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation type="vanished">Külön köszönet:</translation>
    </message>
    <message>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation type="vanished">Az LXQT sok nyelvre le van fordítva, a világban működő fordítóknak köszönhetőn.</translation>
    </message>
</context>
<context>
    <name>LXQt::AddPluginDialog</name>
    <message>
        <source>(%1 active)</source>
        <translation type="vanished">(%1 aktív)</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt Energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>Elaltatás sikertelen</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Vészhitelesítés</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Elaltatás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Készültség</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>Az LXQT készenléte</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Készenléti állapotba akarja helyezni a gépet?&lt;p&gt;A kis energiaszükségletű állapotban feszültségkimaradáskor az újraélesztés nem biztos.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>Az LXQT elaltatása</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Mélykészenléti állapotba akarja helyezni a gépet?&lt;p&gt;A kis energiaszükségletű alvó állapotban feszültségkimaradáskor az újraélesztés nem biztos.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt újraindítás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Újra akarja indítani a gépet? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Ki akarja kapcsolni a gépet? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt kijelentkezés</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Kijelentkezik? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Mélykészenléti állapot sikertelen</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Készenléti állapot sikertelen</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Képernyőzár</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Képvédő indítási hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation type="vanished">Hiba a képernyővédő indításakor.Az xdg-képernyővédő összeomlott.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation type="vanished">Hiba a képernyővédő indításakor.Az xdg-képernyővédő nincs jól telepítve.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation type="vanished">Hiba a képernyővédő indításakor.Az xdg-képernyővédő indíthatatlan.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Hiba a képernyővédő indításakor.Az xdg-képernyővédő indító paramétere hibás.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Hiba a képernyővédő indításakor.Az xdg-képernyővédő telepített és futtatható?</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Hiba a képernyővédő indításakor.Az &apos;activate&apos; sikertelen. Az xdg-képernyővédő telepített és futtatható?</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation type="vanished">Hiba a képernyővédő indításakor.Ismeretlen hiba - az xdg-képernyővédő ismeretlen hibakóddal kilépett=%1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>A QDBusInterface érvénytelen</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Energiakezelő hiba (D-BUS hívás)</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About LXQt</source>
        <translation type="vanished">Az LXQT -ről</translation>
    </message>
    <message>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation type="vanished">Rólunk</translation>
    </message>
    <message>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Szerzők</translation>
    </message>
    <message>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Köszönet</translation>
    </message>
    <message>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Fordítások</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation type="vanished">Technikai háttér</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="vanished">Vágólapra másol</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/liblxqt/liblxqt_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Párbeszédablak</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt Energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Elaltatás sikertelen.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Vészhitelesítés</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Elaltatás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Készültség</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Az LXQT készenléte</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Készenléti állapotba akarja helyezni a gépet?&lt;p&gt;A kis energiaszükségletű állapotban feszültségkimaradáskor az újraélesztés nem biztos.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Az LXQT elaltatása</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Mélykészenléti állapotba akarja helyezni a gépet?&lt;p&gt;A kis energiaszükségletű alvó állapotban feszültségkimaradáskor az újraélesztés nem biztos.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt újraindítás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Újra akarja indítani a gépet? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt kikapcsolás</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Ki akarja kapcsolni a gépet? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt kijelentkezés</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Kijelentkezik? Minden mentetlen munka elvész...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Mélykészenléti állapot sikertelen.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Készenléti állapot sikertelen.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Képernyőzár</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Képernyővédő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Hiba a képernyővédő indításakor.Az xdg-képernyővédő indító paramétere hibás.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="162"/>
        <location filename="../../lxqtscreensaver.cpp" line="168"/>
        <location filename="../../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Képvédő indítási hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Hiba a képernyővédő indításakor. Az xdg-képernyővédő telepített és indítható legyen.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Hiba a képernyővédő indításakor. AZ aktiválás sikertelen. Az xdg-képernyővédő telepített és indítható legyen.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Hiba a képernyővédő indításakor. Az xdg-screensaver ismeretlen és dokumentálatlan hibakódja: %1.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Energiakezelő hiba</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>A QDBusInterface érvénytelen</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Energiakezelő hiba (D-BUS hívás)</translation>
    </message>
</context>
</TS>
